# static_summaries.py

# 中文静态建议
STATIC_RECOMMENDATIONS_ZH = {
    "baseline_scenario": {
        "policymaker": """政策制定者视角：重构住房过滤机制，推动结构优化与品质提升的制度性转型    
在基准情景下，尽管住房市场整体运行平稳，但低质量房源积聚、二手房流通不畅、租购路径脱节等结构性问题逐步显现，反映出当前住房供给结构与家庭居住行为之间存在系统性错位。政策制定者应从供给调控、品质分层、路径衔接等角度，推动住房系统由“总量均衡”向“结构优化”转型。
1. 协同年度住房计划与轮候机制，优化保障房分布结构
建议将住房发展年度计划与轮候管理制度协同运行，构建基于家庭收入、居住状况、租住年限与品质条件的多维轮候优先模型，从而精准识别过滤链条中段的结构堵点。通过“以需定建、以需定购”机制动态调整配售型保障房的区域布局与供给比例，优先满足中等收入家庭的改善型住房需求，提升中段住房的可达性与轮换效率。
2. 建立“品质评级+税收激励”机制，提升二手房市场结构引导功能
为促进二手房品质优化与流转效率，建议构建全国统一的房屋品质分级体系，将房龄、建筑结构、安全性、物业服务等指标纳入评级参考。对评级达标房源实施契税减免、交易流程简化等政策支持，引导高品质房源优先释放，降低改善型购房门槛，缓解中等收入家庭置换障碍，促进住房市场的品质分层流动。
3. 将城市更新纳入住房结构调控工具，推动“以改代建”结构替代
在现有城市更新框架基础上，建议以片区为单元实施“设施升级—住房重构—存量替代”三位一体改造方案。通过专项债、住房养老金与中央补助等资金统筹支持重点区域更新，重点改造老旧小区与功能失衡片区。将更新后房源纳入保障性或限价住房供应体系，推动结构性存量替代，改善城市住房质量与分布结构。
4. 完善租购路径衔接机制，支持稳定租户向自有住房跃迁
建议在核心区或交通便利片区设立“租购转换保障区”，对租住年限达到门槛、信用记录良好且连续参保的家庭，在限价房、保障房供给中赋予优先资格。可结合各地“积分落户”“轮候排位”等机制，建立稳定租户支持通道，引导租购路径衔接，提升住房系统的弹性与纵向可达性。

""",
        "regulator": """市场监管者视角：聚焦品质风险防控、链条畅通与交易中介合规的监管机制重塑 
在基准情景下，住房市场表面运行平稳，但房源品质下行、过滤链中段流转受阻，以及中介和平台在信息披露、行为规范方面存在制度空档，逐渐转化为影响过滤效率与结构公平性的系统性挑战。监管者应从品质监测、制度流程、行为规范与金融协同等四个层面，构建住房交易领域的多维机制监管体系。
1. 建立住房品质风险动态监测系统，提升空间精准治理能力
建议构建以房龄、结构、能耗、物业服务等维度为基础的“住房品质风险图谱”，动态识别品质下行片区，并设置预警阈值。一旦低品质房源占比持续上升，即可触发土地供给调整、金融准入限制等差异化政策干预。配套引导专项债与城市更新资金向此类区域倾斜，实现城市空间中的精准化品质调控。
2. 推动交易制度与信息平台标准化，打通全流程可视链条
在二手房交易环节，建议全面推行“带押过户+抵押注销同步”机制，降低改善型购房者流转成本。同步建设全国统一住房交易信息平台，实现房源、抵押、贷款与税费数据接口对接，构建“全流程可视化+可监测+可预警”的信息管理系统，有效打破当前交易链条中的信息孤岛，提升交易效率与透明度。
3. 构建中介信用监管体系，推动行为规范与平台自律并重
针对中介行为中的虚假宣传、隐瞒抵押与价格误导问题，建议建立以信用评分与违规记录公示为基础的城市级中介分级监管体系。信用等级应作为平台房源挂载、项目准入与服务资质的核心依据，并与税务、人社等数据系统联通，形成跨部门联合惩戒与服务激励双向机制。
4. 将“白名单+融资协同”机制延伸至存量房市场，实现信贷风险结构控制
建议在现有保障性住房融资机制基础上，探索设立“二手房交易白名单”制度。对符合品质评级、交易稳定性与信用记录要求的房源项目，金融机构可给予利率优惠与配套贷款产品。通过金融资源的结构引导，提升高品质二手房流通率，缓解改善性需求“价高门槛”困境，同时保障信贷风险的可控性与投放精准性。
""",
        "analyst": """分析师／研究者视角：聚焦结构指标构建、理论机制建模与政策反馈路径的系统性研究任务  
基准情景呈现出“表面稳态–结构劣化–链条卡点”的典型演化轨迹，住房系统虽具流动性表征，但品质层级、路径通畅性与行为公平性均未得到有效改善。研究者应在指标设计、理论建模、数据支撑与反馈机制四个维度深化政策性研究，为住房过滤机制的制度建构与政策修正提供技术基础。
1. 构建面向过滤效率与品质结构的核心指标体系
建议设立“住房过滤指数（HFI）”“租购转换指数（RTR）”与“住房品质结构指数（PQI）”，系统评估住房链条中不同群体的置换通畅性、租购路径可达性及房源品质的分布演化。这些指标应嵌入城市住房发展年度计划与住房保障分配决策，提升政策调整的结构敏感性与量化支撑能力。
2. 建立跨群体行为建模与机制传导分析框架
基于过滤链条运行逻辑，构建涵盖金融变量、供给结构、行为响应与住房轨迹的多群体建模系统。模型应明确不同收入群体在信贷、税费、补贴等干预因素下的行为跃迁路径，支持“前评估–中期校准–后反馈”的动态模拟，用于政策设计与策略选型的机制实验平台。
3. 推进住房数据标准化集成，建设多源协同数据库平台
建议打通住建、自然资源、税务、民政等多源数据通道，构建集成房源属性、人口结构、交易轨迹与空间信息的多维数据库体系。作为模拟模型的底层支撑，该数据库将为城市间住房制度对比、指标横向分析与政策传导效应识别提供实证基础。
4. 建立制度反馈闭环机制，强化政策模拟成果的场景嵌入
研究机构应常态化发布住房结构监测与补贴评估报告，将模拟结果反馈至住房计划、保障性住房布局与财政支持强度设定中，实现从“模型输入”到“政策调整”的双向循环。建议设立“年度住房结构研判机制”，推动研究成果转化为制度嵌套工具，助力住房系统长期稳态运行与治理能力提升。
"""
    },

    "credit_stimulus_scenario": {
        "policymaker": """政策制定者视角：优化信贷资源配置结构，推动品质导向与群体分层的精准调控机制建设   
在信贷刺激情景下，住房市场活跃度显著上升，改善型需求快速释放，部分中等收入群体实现购房跃迁，过滤链条的流速得到提升。然而，交易结构偏斜、住房品质下行与低收入群体响应不足的问题同步显现，暴露出现行信贷政策在促进住房系统结构协调与质量升级方面的约束。政策制定者需在“金融规则精细化、信贷工具差异化、品质机制制度化”三个层面，系统推进信贷政策从总量刺激转向结构治理。
1. 建议构建差异化信贷准入规则。
强化贷款资源对首套、首改购房群体的倾斜力度，控制多套房持有者贷款通道。可通过设定“购房记录+纳税记录+户籍稳定性”三重识别机制，在限购基础上引入贷款风险等级评估，引导资金流向自住型、改善型真实需求。
2. 应推动信贷定价与房源品质挂钩。
在LPR利率定价机制下，探索将房屋品质分级纳入贷款利率浮动标准，对结构良好、节能达标、服务规范的二手房与新建住房，在利率审批环节给予基点下调，激励高品质房源流转。同步加强金融机构房源评估指引，建立“品质—利率—税收”三元联动机制，提升信贷定向能力。
3. 在住房供给侧，应强化“改善型住房定向供给+信贷配额匹配”的制度协同。
结合城市年度住房发展计划，对品质改善类项目设立信贷通道配额，并优先纳入商品房转保障房机制，提升中等收入群体在高品质区域的置换机会与可得性。
4. 应推动将信贷行为结果嵌入轮候优先机制。
对于连续租住、稳定缴税、存在真实改善需求但尚未购房的群体，建立“购前评估档案”，将其纳入保障房优先配售名单，实现金融政策与保障性供给机制的行为协同，防止金融刺激向结构性套利倾斜。""",
        "regulator": """市场监管者视角：强化品质信息公开与行为监督，引导信贷释放回归结构理性  
信贷刺激情景下，市场交易规模迅速扩大，置换行为显著提速，但同时暴露出房源品质退化、改善型交易高度集中于高收入群体以及中介行为边界模糊等问题。监管职责需从合规审查拓展至交易结构与行为过程，围绕品质信息公开、信贷联审机制、平台行为规范与征信差异化管理等方面，推动信贷释放过程中的市场结构稳健运行。
1. 应加强房源品质信息公示与风险提示。
建议推动建立二手房交易房源基础信息归集制度，涵盖房龄、建筑结构、使用年限、维修记录与物业服务情况等基础维度，统一上传至交易平台展示页面。对集中挂牌、房源老化、交易频率异常的小区，可纳入“交易质量关注名单”，在挂牌端设置风险提示栏，引导消费者理性判断，提升市场信息透明度。
2. 应强化购房贷款审核中的风险识别维度。
金融机构在信贷审批时，应结合借款人交易频率、不动产持有记录与所购房源的结构风险，开展联合评估。对存在短期高频购房行为或交易房源品质明显偏弱的情况，应通过调整利率、控制贷款额度等方式合理调节金融释放节奏，防止“以贷炒旧”等行为扩张。
3. 应建立中介行为分级管理机制。
建议依据中介机构房源合规率、投诉频次、交易真实度等指标建立信用评级体系，分级管理、动态调整。对屡次发布虚假房源、夸大贷款政策、诱导超贷行为的机构，实施限期整改与业务范围限制，引导平台向信息真实、服务合规方向升级。
4. 推动征信数据与住房交易系统的联动应用。
对首次改善型购房人群，在信用记录良好、购房行为稳定的前提下，可给予贷款审批便利与利率优惠；而对短期内多次交易、信用记录波动大者，适当提高准入门槛。通过信用约束机制，引导金融资源优先服务刚需与改善，抑制套利性投机交易，保障住房信贷资源的配置效率与结构稳定。""",
        "analyst": """分析师／研究者视角：评估信贷效率与结构公平性，构建面向过滤链条的金融政策研究工具组 
信贷刺激情景模拟结果揭示出住房市场在“交易活跃度提升”的表象下，隐藏着“品质下滑–结构失衡–群体分化”三重风险。研究者的任务不应止于趋势描述，而需聚焦于机制识别、路径解释与指标构建，以推动信贷政策在未来从总量刺激走向结构优化，从单向放量走向行为分层。
1. 应围绕“信贷效率–过滤公平性”构建核心评估指标体系。
建议设立“信贷覆盖率指数（LCRI）”，用于衡量不同收入群体中贷款获得与改善型行为转化之间的比例关系，捕捉信贷政策在中低收入家庭中的实际渗透力；同时引入“信贷结构偏斜指数（LSDI）”，通过比较高收入与低收入家庭在改善行为占比上的变化趋势，量化信贷红利分配结构是否失衡。二者联合使用，可为信贷政策的横向公平性与纵向效率提供数据支撑。
2. 应构建覆盖群体行为—房源质量—信贷通道三维交叉的过滤链条结构评估模型。
模型应嵌入房源品质等级、贷款利率差异、交易频次与群体置换能力等核心变量，模拟不同信贷强度下链条运行状态的变化路径，识别“以贷炒旧”“品质倒挂”“链条断点”等风险节点，为监管和政策提供机制预警功能。
3. 应推动建立住房金融领域的微观行为数据库与区域级信贷响应档案。
依托多源数据整合，将房贷审批信息、房源特征、交易时序与购房者画像纳入动态数据池，构建可用于模拟分析、参数标定与政策校准的基础研究平台。同时，建议在住房年度计划评估体系中嵌入“信贷流向与品质结构”联动评估模块，将模拟与实证结果作为城市级信贷政策调整的参考依据。
4. 研究机构应主动承担“政策后评估”与“政策实验反馈”的专业职责。
围绕公积金政策调整、LPR利率浮动、契税优化等政策变量开展实证评估，建立“政策-模拟-反馈”三位一体的知识支持机制，为信贷政策从粗放调节向精准调控转型提供理论依据与数据基础。"""
    },

    "fiscal_subsidy_scenario": {
        "policymaker": """政策制定者视角：强化补贴结构分层与制度统筹，推动财政支持向结构优化与路径畅通转型  
在财政补贴情景下，住房交易量大幅上升，低收入与中等收入群体“有房化”水平提升，住房过滤链条下端流动性增强。但补贴效应亦集中于边际房源，住房品质改善不足，租购路径分割未解，暴露出财政政策在“可负担性”提升的同时，仍面临“可住性”与“结构公平性”的约束。为此，应从补贴结构、供给布局、路径衔接与计划统筹四方面推进制度优化。
1. 建立按收入分层和购房阶段设定的差异化财政补贴体系。
对首次购房、低收入家庭提供一次性补贴；对中等收入家庭，侧重契税减免、公积金贴息等间接支持，避免统一补贴导致资金集中与行为扭曲。同时，将住房品质纳入补贴发放前置条件，优先支持结构安全、绿色节能的房源，确保财政资源导向品质改善。
2. 发挥财政在供给端的结构引导功能。
结合“以需定建、以需定购”，扩大配售型保障房与限价房比例，在中等收入群体集中、二手房流通受限的区域优先布局。鼓励地方通过“收购+改造+补贴”方式将存量商品房转为政策性住房，提高财政资金撬动效率，缓解改善型房源结构性不足问题。
3. 应强化租购路径之间的结构性衔接机制。
对稳定租赁满一定年限、信用记录良好、连续缴纳社保与个税的家庭，可在保障性住房或限价房项目中获得优先参与权或积分加权，引导财政支持向具备长期居住稳定性的新市民、青年家庭精准覆盖，推动从租赁保障向产权购置的梯度跃迁。
4. 建议将购房补贴与地方住房保障名册、住房发展年度计划实行联审联批机制。
对已进入保障房轮候系统的家庭优先发放补贴；对边缘性刚需群体由地方制定专项补贴安排，实现补贴对象识别、房源供给与财政计划的闭环协同，推动补贴精准落位、财政资源动态调配。 """,
        "regulator": """市场监管者视角：完善实施配套与交易规范机制，保障财政补贴政策效果落地可控    
在财政补贴情景下，住房市场交易总量扩大、低收入群体购房比例提升，对激发市场交易积极性、改善低收入与新市民群体居住条件具有重要意义。监管部门应从实施环节出发，围绕房源品质、购房行为、平台服务与项目审核建立规范支持机制，为财政资源精准投放与市场稳定运行提供制度保障。
1. 应在地方财政补贴实施方案中明确房源品质合规要求。
建议对补贴可适用房源设定底线标准，如房龄不超过一定年限、建筑结构合规、物业服务稳定等，引导补贴资金优先用于品质可靠、使用年限充足的住房类型。平台可设立“可补贴房源”标识机制，提高交易信息透明度，协助购房人理性选择。
2. 完善补贴申请审核机制与流程合规性核查。
建议依托不动产登记、社保、税务等部门信息系统联通，对购房人资格条件进行前置验证，确保补贴优先覆盖首购群体、稳定就业人群与改善型家庭。同时推动建立抽查核验机制，对补贴使用与房源属性开展定期追踪，确保资金使用符合政策初衷。
3. 应规范中介与平台在补贴实施过程中的服务行为。
鼓励平台展示补贴适用项目清单、贷款模拟工具、服务流程提示等信息功能，提升用户政策知晓度与操作便利性。对于中介服务环节，应强化合规引导，支持公开比价、服务透明与收费规范，营造公平交易环境，防止因信息不对称带来的非理性购房行为。
4. 建议地方财政补贴房源与项目准入机制实现协同。
对可纳入政策支持的商品房项目或地方收购房源，应参考“住房项目名录制”经验，设立“财政支持房源清单”，明确房源基本条件与开发企业规范标准。推动财政、住建与金融监管协同管理，实现“项目入库、资金审核、交付监管”全流程闭环。""",
        "analyst": """分析师／研究者视角：评估补贴政策结构效应，强化政策反馈机制与系统优化路径  
财政补贴作为提高住房可负担性的重要政策工具，在提升中低收入群体购房能力、增强市场包容性方面成效明显。模拟结果显示，补贴推动住房过滤链下端流动增强，低收入家庭“有房化”水平上升，整体交易活跃度提高。下一阶段，研究工作应从结构评估、机制设计与数据反馈等方面，为政策优化提供支持。
1. 建议构建面向结构公平与品质改善的财政补贴绩效评估体系。
除覆盖率与资金使用率外，应引入“结构改善效应指数（SEI）”与“群体可达性指数（GAI）”，用于衡量补贴投放对及同收入群体获得能力提升的实际影响，使政策成效在“总量–结构–行为”三个层面具备可量化基础。
2. 应设计可模拟不同补贴结构、强度与行为路径的政策实验模型。
模型应结合房源品质、购房能力与城市区位特征，识别补贴政策在改善型购房、长期租转购行为中的边际影响，探索最优补贴设计对中低收入群体改善型购房与租购衔接行为的引导作用，为分层支持路径提供参数参考。
3. 推动财政补贴与住房供给、空间结构联动分析。
整合补贴发放数据、房源品质数据库与住房发展年度计划，建立“补贴投放—市场响应—规划调整”反馈机制，增强财政工具的空间调节能力与结构引导功能。
4. 建议建立财政补贴政策的常态化研究与反馈机制。
研究机构应定期发布补贴成效分析报告，对资金流向、受益群体、房源类型与结构变化等核心维度开展追踪研究，为财政政策优化与供需平衡提供专业支撑，推动财政工具从静态补贴向动态调控转型，服务住房系统的结构韧性与多层次发展目标。"""
    }
}

# English static recommendations
STATIC_RECOMMENDATIONS_EN = {
    "baseline_scenario": {
        "policymaker": """(Policymaker · Baseline Scenario) 
        The baseline scenario reveals a stable housing market on the surface, yet systemic mismatches persist between supply structure and household behavior.  
        1. Integrate annual housing development plans with a dynamic waitlist system.   
        Build a prioritization model based on income, tenure, and housing quality to identify mid-chain demand bottlenecks. Adjust the distribution of shared-ownership housing using “build-to-need” principles.   
        2. Introduce a quality-based tax incentive mechanism.   
        Develop a rating system for housing quality and offer deed tax discounts for highly rated stock. This encourages middle-income families to upgrade and improves filtering mobility.     
        3. Treat urban renewal as a core structural tool.   
        Use special bonds and housing pension funds to finance redevelopment in aged or low-functioning areas. Include renewed housing into the guaranteed supply system to improve both quality and structure.     
        4. Establish rental-to-ownership transition zones.    
        Grant purchase priority to long-term renters with stable credit and tax contributions. This closes the rental–ownership divide and supports upward mobility within the housing system.      
        """,

        "regulator": """(Regulator · Baseline Scenario) 
        Though the baseline market appears stable, deeper structural vulnerabilities—such as quality degradation, circulation blockages, and lax regulatory coverage—are emerging. A more comprehensive regulatory approach is needed, combining quality monitoring, transaction transparency, behavioral oversight, and credit-based mechanisms.   
        1. Establish a dynamic housing quality monitoring system.    
        Integrate indicators such as building age, structural integrity, energy performance, and property management into a real-time “quality heatmap.” When low-rated units become overly concentrated in certain areas, this should trigger differentiated land supply rules and financing access controls, alongside targeted urban renewal investment to reallocate resources effectively.    
        2. Promote unified transaction processes and integrated housing information platforms.      
        Broad implementation of “mortgage-with-title-transfer + simultaneous lien release” protocols is essential. A national housing transaction platform should connect ownership, lien, loan, and tax data, ensuring transparency and end-to-end traceability in second-hand housing flows.    
        3. Build a city-level credit-based intermediary regulation system.      
        Agencies and agents with verified misconduct—such as false listings or deliberate information withholding—should be ranked through a public credit evaluation mechanism. These scores should influence their platform visibility, licensing, and access to public incentive programs, supported by cross-department data-sharing with tax and labor authorities.     
        4. Extend the “white list + financing coordination” system to the second-hand market.       
        Based on existing affordable housing financing practices, a whitelist for eligible resale properties should be created. Financial institutions should provide favorable terms for quality-assured listings, steering capital toward trustworthy stock and supporting structural filtering improvements without amplifying systemic risk.     
        """,

        "analyst": """(Analyst · Baseline Scenario) 
        The baseline scenario demonstrates a steady macro market underpinned by filtering inefficiencies and structural stagnation. Persistent quality decline and circulation bottlenecks suggest a need for deeper institutional analysis and evidence-based policy simulation. Researchers should focus on indicator systems, theoretical frameworks, and policy feedback channels to guide long-term reform.
        
        1. Develop a suite of structural housing indicators.    
        These should include a Housing Filtering Index (HFI) to measure upward movement across income strata, a Rental-to-Ownership Transition Index (RTR) to assess conversion efficiency, and a Physical Quality Index (PQI) to track spatial quality distributions. These metrics should inform both annual housing plans and the allocation logic of subsidized housing supply. 
        2. Construct multi-group behavioral simulation models.  
        A filtering mechanism model should reflect the interaction of household behavior with mortgage terms, taxation, and supply quality. It should support scenario-based simulation, with embedded modules for ex ante evaluation, mid-term adjustment, and ex post feedback, enabling the testing of structural interventions and policy pathways. 
        3. Standardize and integrate multi-source housing datasets.     
        Link housing registry, land use, taxation, and civil records to form a micro-level housing behavior database. This will support regional comparisons, longitudinal structural analysis, and evaluation of spatial equity impacts in response to policy shocks.  
        4. Institutionalize model-informed policy feedback loops.   
        Research bodies should publish periodic housing structure and filtering performance reports. Simulation results should be embedded into subsidy planning, housing layout, and urban development strategies. A formal annual housing structure review mechanism should ensure research outputs are translated into planning and investment decisions.    
        """},

    "credit_stimulus_scenario": {
        "policymaker": """(Policymaker · Credit Stimulus Scenario)     
    Under the credit stimulus scenario, housing market activity significantly increases, and demand for upgrading is quickly released. Some middle-income households achieve homeownership, and filtering becomes more dynamic. However, emerging issues include credit flow imbalances, declining housing quality, and limited responses among low-income groups. Policymakers should steer credit policy from broad stimulus toward structured governance through the following:  
    1. Establish differentiated mortgage access policies.   
    Credit allocation should prioritize first-time and first-upgrading buyers while curbing financing for multi-property investors. A three-tier screening mechanism—based on purchase records, tax contributions, and household registration—can channel resources toward genuine housing demand.    
    2. Link mortgage pricing to housing quality.    
     Within the LPR framework, quality-certified properties should receive interest rate discounts. Banks should adopt a "quality–interest–tax" alignment system, where better-rated housing benefits from lower rates and related tax incentives, thus directing credit flows toward structural improvement.   
    3. Coordinate housing supply targets with mortgage quotas.  
     Local housing plans should reserve credit quotas for certified improvement-oriented projects. Privately owned stock can be converted to subsidized housing through public acquisition, expanding mid-range supply and enhancing access for middle-income households.   
    4. Integrate credit behavior with eligibility prioritization.   
    For renters who meet stability, contribution, and need criteria, a "pre-approval dossier" should be created and linked to guaranteed housing allocation priority. This helps align credit behavior with fair housing access and deters speculative borrowing. 
    """,

        "regulator": """(Regulator · Credit Stimulus Scenario)  
    The credit stimulus scenario accelerates transactions, but also reveals structural frictions—especially around housing quality decline, over-concentration of credit among higher-income groups, and growing intermediary misconduct. Regulatory strategies must support transaction scale-up while preserving transparency and structural integrity.   
    1. Enhance public visibility of housing quality data.   
    Platforms should display key metrics for resale listings—such as building age, structure type, repair history, and management status. Neighborhoods with high transaction volumes but weak structural quality should be flagged through a "Quality Watch List." 
    2. Integrate housing quality into loan approval risk filters.   
    Loan assessments should consider borrower frequency, asset attributes, and price-quality mismatch. Applicants seeking low-quality properties at high transaction speeds should undergo tighter scrutiny and differentiated pricing terms.   
    3. Introduce tiered regulatory oversight of intermediaries.     
    Platforms and agencies should be evaluated based on accuracy, complaints, and transaction reliability. Credit ratings should determine listing rights and service access. Persistent violators should face rectification mandates and platform restrictions.    
    4. Strengthen integration between credit records and housing transactions.  
    Qualified borrowers with positive histories may receive streamlined approval and interest concessions. Those with speculative patterns or volatile profiles should face stricter thresholds. This system aligns credit accountability with structural housing equity.   
    """,

        "analyst": """(Analyst · Credit Stimulus Scenario)  
    The credit stimulus scenario expands liquidity but raises concerns about structural efficiency, distributional fairness, and sustainability. Researchers must go beyond volume metrics and examine the interaction between credit policy, housing quality, and group behavior.  
    1. Build a dual index system    
    The Loan Coverage Ratio Index (LCRI) measures mortgage access equity across income groups, while the Loan Skewness Differential Index (LSDI) tracks concentration among high-income buyers. Together, they quantify vertical fairness and horizontal inclusiveness in credit allocation.    
    2. Simulate filtering chains with cross-dimensional variables.  
    Behavioral models should integrate property quality ratings, borrowing costs, transaction frequency, and demographic profiles to predict how credit pathways affect upward mobility and system resilience.  
    3. Construct a behaviorally responsive micro-database.  
    Mortgage applications, listing details, buyer demographics, and transaction timelines should be linked to assess the credit structure’s alignment with housing needs. This informs real-time calibration and spatial targeting of housing credit policy.    
    4. Institutionalize policy feedback loops grounded in modeling.     
    Scenario-based testing should evaluate impacts of LPR adjustments, tax reliefs, and subsidy layering. A policy–simulation–response mechanism will help transform credit regulation from blanket easing toward adaptive precision targeting. 
    """
    },


    "fiscal_subsidy_scenario": {
    "policymaker": """(Policymaker · Fiscal Subsidy Scenario)   
    In the fiscal subsidy scenario, housing transaction volumes increase significantly, with notable gains in ownership rates among low- and middle-income households. Filtering improves at the lower end of the market. However, subsidies tend to concentrate on marginal units, while structural quality and rental–ownership pathways remain weak. Policymakers should enhance the subsidy system by focusing on four coordinated dimensions:  
1. Design tiered subsidies based on income and housing stage.   
 Direct subsidies should be prioritized for first-time buyers and low-income groups, while tax relief and mortgage interest support are better suited to middle-income households. Housing quality standards should be preconditions for eligibility to ensure subsidies promote structural upgrades.   
2. Strengthen supply-side alignment using fiscal levers.    
 Guided by “build-to-need” and “purchase-to-need” strategies, increase the share of shared-ownership and price-capped housing. Government acquisition and renovation of existing stock should supplement supply in constrained districts, enhancing fiscal leverage and supply responsiveness.  
3. Facilitate rental-to-ownership transitions through structural mechanisms.    
Stable renters with verified credit and continuous tax/social insurance records should receive prioritized access or scoring advantages in public housing schemes. This bridges rental and ownership systems, supporting upward mobility for young workers and urban newcomers. 
4. Integrate subsidy distribution with housing plans and population registries.     
Cross-reference local housing development plans with housing eligibility lists to coordinate target groups, resource allocation, and annual budgets. This builds a closed-loop feedback system to ensure dynamic, need-based fiscal resource deployment.    
""",

    "regulator": """(Regulator · Fiscal Subsidy Scenario)   
Fiscal subsidies enhance affordability and stimulate low-end transaction activity. However, implementation requires strict regulatory coordination to ensure that funds flow toward structurally sound, policy-aligned housing and avoid speculative misuse. Regulators should focus on four key safeguards:    
1. Define quality compliance thresholds for subsidized properties.   
Set clear criteria for age, structural integrity, and service standards. Local platforms should label eligible listings accordingly, helping buyers identify suitable homes and directing funds toward viable assets.   
2. Verify applicant eligibility through cross-agency integration.   
Link housing applications with tax, social insurance, and property registries to confirm first-time ownership status and employment stability. Post-approval sampling audits should be used to detect misuse or misreporting.   
3. Regulate platform and intermediary behavior during subsidy campaigns.    
Encourage clear disclosure of eligible projects, mortgage tools, and support channels. Platforms should monitor agency behavior and penalize exaggeration, hidden fees, or buyer manipulation that distorts subsidy targeting.  
4. Align fiscal housing projects with standardized whitelist criteria.  
Properties supported by public funds or earmarked for conversion should meet predefined quality and developer eligibility standards. A cross-sector approval and supervision framework should link project selection, funding authorization, and delivery quality control.  
""",

    "analyst": """(Analyst · Fiscal Subsidy Scenario)    
Fiscal subsidies are pivotal in expanding affordability and enabling lower-income access to ownership. Simulations show improved filtering at the base of the market and stronger participation from disadvantaged groups. Research should now focus on refining subsidy structures, spatial targeting, and policy responsiveness.  
1. Build a performance evaluation framework linking subsidy inputs to structural outcomes.  
Indicators like the Structural Equity Improvement Index (SEI) and Group Access Index (GAI) should assess effectiveness across quality and inclusion dimensions. 
2. Simulate policy variants for differential targeting.     
Models should test how subsidy size, distribution, and eligibility criteria influence behavioral responses among renters, first-time buyers, and improvers. Output supports tiered program design and market segmentation alignment.    
3. Connect fiscal distribution to housing quality and spatial planning.     
Build datasets linking subsidies to unit quality, geography, and regional housing needs. Develop a “spending–response–plan adjustment” feedback tool to guide flexible subsidy calibration. 
4. Institutionalize feedback mechanisms for iterative policy reform.    
Annual reports should track subsidy flow, target coverage, and structural impacts. Findings should inform subsidy budget design, housing allocation priorities, and mid-term strategy revisions to optimize long-run housing system resilience. 
""",
    }
}